@@ -438,7 +438,15 @@ PropertyEditorImpl.prototype.updateGui = function(onlyChanges) {
             //qDebug("value: ", value);
 
             var attributes = this.getPropertyAttributes(group, title);
-            var propertyTypeId = attributes.getPropertyTypeId();
+            //var propertyTypeId = attributes.getPropertyTypeId();
+            var propertyTypeId = RPropertyTypeId.getPropertyTypeId(group, title);
+
+            if (propertyTypeId.getId()===-1) {
+                // property is custom property
+                // make sure it knows it's titles, etc:
+                propertyTypeId.setCustomPropertyTitle(RSettings.getAppId());
+                propertyTypeId.setCustomPropertyName(title);
+            }
 
             //qDebug("isMixed: ", attributes.isMixed());
 
@@ -573,8 +581,18 @@ PropertyEditorImpl.prototype.updateGui = function(onlyChanges) {
 
                 var controls = undefined;
                 if (!isNull(gridLayout)) {
-                    // don't display any Z values:
-                    if (RSettings.getBoolValue("PropertyEditor/ShowZCoordinates", false)===false && title==="Z" && !propertyTypeId.isCustom()) {
+                    // don't display any Z values or polyline elevation:
+                    var hide = false;
+                    if (!propertyTypeId.isCustom()) {
+                        if (RSettings.getBoolValue("PropertyEditor/ShowZCoordinates", false)===false) {
+                            if (title===RPolylineEntity.PropertyVertexNZ.getPropertyTitle() ||
+                                title===RPolylineEntity.PropertyElevation.getPropertyTitle()) {
+                                hide = true;
+                            }
+                        }
+                    }
+
+                    if (hide) {
                         controls = undefined;
                     }
                     else {
@@ -755,6 +773,20 @@ PropertyEditorImpl.prototype.initControls = function(propertyTypeId, onlyChanges
         }
     }
 
+    // property available on request:
+    // add button to request all properties:
+    if (attributes.isOnRequest()) {
+        var requestAllButton = new QToolButton(this.geometryGroup);
+        requestAllButton.objectName = objectName + "_request";
+        requestAllButton.text = qsTr("Show");
+        requestAllButton.toolTip = qsTr("Show all properties");
+        requestAllButton.clicked.connect(this, "requestAllProperties");
+        requestAllButton.setSizePolicy(QSizePolicy.Ignored, QSizePolicy.Preferred);
+
+        return new Array(requestAllButton);
+    }
+
+
     // Layer:
 //    if (propertyTypeId.getId()===REntity.PropertyLayer.getId()) {
 //        WidgetFactory.initLayerCombo(control, EAction.getDocument());
@@ -765,20 +797,27 @@ PropertyEditorImpl.prototype.initControls = function(propertyTypeId, onlyChanges
     if (propertyTypeId.getId()===RTextEntity.PropertyHAlign.getId()) {
         controls = this.initChoiceControls(
                     objectName, propertyTypeId, onlyChanges, control, false, true);
-//                    [ qsTr("Left"), qsTr("Center"), qsTr("Right"),
-//                      qsTr("Aligned"), qsTr("Middle"), qsTr("Fit")],
-//                    [ RS.HAlignLeft, RS.HAlignCenter, RS.HAlignRight,
-//                      RS.HAlignAlign, RS.HAlignMid, RS.HAlignFit]);
     }
 
     // Vertical alignment: combo box:
     else if (propertyTypeId.getId()===RTextEntity.PropertyVAlign.getId()) {
         controls = this.initChoiceControls(
                     objectName, propertyTypeId, onlyChanges, control, false, true);
-//                    [qsTr("Top"), qsTr("Middle"), qsTr("Base"), qsTr("Bottom")],
-//                    [RS.VAlignTop, RS.VAlignMiddle, RS.VAlignBase, RS.VAlignBottom]);
     }
 
+    // Polyline orientation: combo box:
+    else if (propertyTypeId.getId()===RPolylineEntity.PropertyOrientation.getId()) {
+        controls = this.initChoiceControls(
+                    objectName, propertyTypeId, onlyChanges, control, false, true);
+    }
+
+    // Arc dimension arc symbol type: combo box:
+    else if (propertyTypeId.getId()===RDimArcLengthEntity.PropertyDimArcSymbolType.getId()) {
+        controls = this.initChoiceControls(
+                    objectName, propertyTypeId, onlyChanges, control, false, true);
+    }
+
+
     // Hatch pattern: combo box with hatch names:
     else if (propertyTypeId.getId()===RHatchEntity.PropertyPatternName.getId()) {
         var patternNames = undefined;
@@ -899,6 +938,10 @@ PropertyEditorImpl.prototype.initNumberControls = function(objectName, propertyT
         if (attributes.isAngleType()) {
             control.setAngle(true);
         }
+        // TODO: support scale in RMathLineEdit:
+//        if (attributes.isScaleType()) {
+//            control.setScale(true);
+//        }
         control.objectName = objectName;
     }
 
@@ -1113,6 +1156,12 @@ PropertyEditorImpl.prototype.initChoiceControls = function(
     else if (propertyTypeId.getId()===RTextEntity.PropertyVAlign.getId()) {
         WidgetFactory.initVAlignCombo(control);
     }
+    else if (propertyTypeId.getId()===RPolylineEntity.PropertyOrientation.getId()) {
+        WidgetFactory.initOrientationCombo(control);
+    }
+    else if (propertyTypeId.getId()===RDimArcLengthEntity.PropertyDimArcSymbolType.getId()) {
+        WidgetFactory.initArcSymbolTypeCombo(control);
+    }
     else if (isOfType(control, QComboBox) /*&& propertyTypeId.getId()!==REntity.PropertyLayer.getId()*/) {
         control.clear();
         if (isNull(choices)) {
@@ -1247,6 +1296,24 @@ PropertyEditorImpl.prototype.filterChanged = function() {
     this.updateFromDocument(doc, false, entityTypeFilter, true);
 };
 
+/**
+ * Called when the user requests all properties to be shown.
+ */
+PropertyEditorImpl.prototype.requestAllProperties = function() {
+    var doc = EAction.getDocument();
+    if (isNull(doc)) {
+        return;
+    }
+
+    var selectionCombo = this.widget.findChild("Selection");
+    var entityTypeFilter = selectionCombo.itemData(selectionCombo.currentIndex);
+    if (isNull(entityTypeFilter)) {
+        entityTypeFilter = RS.EntityAll;
+    }
+
+    this.updateFromDocument(doc, false, entityTypeFilter, true, true);
+};
+
 PropertyEditorImpl.prototype.getAdjustedPropertyValue = function(propertyTypeId) {
     // show handle as hex reprensentation (string):
     if (propertyTypeId.getId()===RObject.PropertyHandle.getId()) {
